#ifndef QATOOLS_UTILITY_H
#define QATOOLS_UTILITY_H

#include <iostream>
#include <fstream>
#include <vector>
#include <algorithm>
#include <iterator>
#include <cassert>
#include <sstream>
#include <string>

#include <Rtypes.h>
#include <TString.h>
#include <TChain.h>
#include <TEnv.h>

#include <qaEvent.h>
#include <qaParticle.h>

class qaUtility
{
protected:
  qaUtility();
  virtual ~qaUtility();
  static qaUtility *fUtility;

public:
  qaUtility(qaUtility &other) = delete;
  void operator=(const qaUtility &) = delete;

  static qaUtility *GetInstance();

  const Double_t error_code = -999.;
  const Int_t npid = 10;
  const std::vector<Int_t> vpdg = {0, 211, 321, 2212, 2112, 0, -211, -321, -2212, -2112};
  const std::vector<Double_t> mpdg = {error_code, 0.13957, 0.493677, 0.938272, 0.88277299, error_code, 0.13957, 0.493677, 0.938272, 0.88277299};
  const Int_t maxCentBins = 20;

  Int_t Nevents;
  Int_t debug;
  std::string format;

  TChain *initChain(const TString &inputFileName, const char *chainName);

  std::vector<Float_t> ParseVector(std::string _input);
  Bool_t initCentrality();

  Double_t GetCharge(Int_t pdg);
  Int_t GetPdgId(Int_t pdg);

  ClassDef(qaUtility, 0);
}; // class qaUtility

#endif
